@@ -13,7 +13,7 @@ Usage::
     list_servers_paginator: ListServersPaginator = client.get_paginator("list_servers")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_transfer.type_defs import ListServersResponseTypeDef, PaginatorConfigTypeDef
 
@@ -23,12 +23,12 @@ __all__ = ("ListServersPaginator",)
 
 class ListServersPaginator(Boto3Paginator):
     """
-    [Paginator.ListServers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/transfer.html#Transfer.Paginator.ListServers)
+    [Paginator.ListServers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/transfer.html#Transfer.Paginator.ListServers)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListServersResponseTypeDef, None, None]:
+    ) -> Iterator[ListServersResponseTypeDef]:
         """
-        [ListServers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/transfer.html#Transfer.Paginator.ListServers.paginate)
+        [ListServers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/transfer.html#Transfer.Paginator.ListServers.paginate)
         """
